@@ -11,10 +11,11 @@ from pathlib import Path
 from typing import Dict, List, Optional, Set, Union
 
 import numpy as np
+from shapely.geometry.geo import shape
 from tqdm import tqdm
 
 from sahi.utils.file import load_json, save_json
-from sahi.utils.shapely import ShapelyAnnotation, box, get_shapely_multipolygon
+from sahi.utils.shapely import ShapelyAnnotation, box, get_bbox_from_shapely, get_shapely_multipolygon
 
 
 class CocoCategory:
@@ -765,6 +766,7 @@ class Coco:
         image_dir=None,
         remapping_dict=None,
         ignore_negative_samples=False,
+        clip_bboxes_to_img_dims=False,
     ):
         """
         Creates Coco object.
@@ -786,6 +788,7 @@ class Coco:
         self.categories = []
         self.images = []
         self._stats = None
+        self.clip_bboxes_to_img_dims = clip_bboxes_to_img_dims
 
     def add_categories_from_coco_category_list(self, coco_category_list):
         """
@@ -945,6 +948,7 @@ class Coco:
         image_dir: Optional[str] = None,
         remapping_dict: Optional[Dict] = None,
         ignore_negative_samples: bool = False,
+        clip_bboxes_to_img_dims: bool = False,
     ):
         """
         Creates coco object from COCO formatted dict or COCO dataset file path.
@@ -959,6 +963,8 @@ class Coco:
                 {1:0, 2:1} maps category id 1 to 0 and category id 2 to 1
             ignore_negative_samples: bool
                 If True ignores images without annotations in all operations.
+            clip_bboxes_to_img_dims: bool = False
+                Limits bounding boxes to image dimensions.
 
         Properties:
             images: list of CocoImage
@@ -969,6 +975,7 @@ class Coco:
             image_dir=image_dir,
             remapping_dict=remapping_dict,
             ignore_negative_samples=ignore_negative_samples,
+            clip_bboxes_to_img_dims=clip_bboxes_to_img_dims,
         )
 
         assert (
@@ -1017,6 +1024,8 @@ class Coco:
                 coco_image.add_annotation(coco_annotation)
             coco.add_image(coco_image)
 
+        if clip_bboxes_to_img_dims:
+            coco = coco.get_coco_with_clipped_bboxes()
         return coco
 
     @property
@@ -1406,6 +1415,42 @@ class Coco:
 
         return area_filtered_coco
 
+    def get_coco_with_clipped_bboxes(self):
+        """
+        Limits overflowing bounding boxes to image dimensions.
+        """
+        from sahi.slicing import annotation_inside_slice
+
+        coco = Coco(
+            name=self.name,
+            image_dir=self.image_dir,
+            remapping_dict=self.remapping_dict,
+            ignore_negative_samples=self.ignore_negative_samples,
+        )
+        coco.add_categories_from_coco_category_list(self.json_categories)
+
+        for coco_img in self.images:
+            img_dims = [0, 0, coco_img.width, coco_img.height]
+            coco_image = CocoImage(
+                file_name=coco_img.file_name, height=coco_img.height, width=coco_img.width, id=coco_img.id
+            )
+            for coco_ann in coco_img.annotations:
+                ann_dict: Dict = coco_ann.json
+                if annotation_inside_slice(annotation=ann_dict, slice_bbox=img_dims):
+                    shapely_ann = coco_ann.get_sliced_coco_annotation(img_dims)
+                    bbox = ShapelyAnnotation.to_coco_bbox(shapely_ann._shapely_annotation)
+                    coco_ann_from_shapely = CocoAnnotation(
+                        bbox=bbox,
+                        category_id=coco_ann.category_id,
+                        category_name=coco_ann.category_name,
+                        image_id=coco_ann.image_id,
+                    )
+                    coco_image.add_annotation(coco_ann_from_shapely)
+                else:
+                    continue
+            coco.add_image(coco_image)
+        return coco
+
 
 def export_yolov5_images_and_txts_from_coco_object(output_dir, coco, ignore_negative_samples=False, mp=False):
     """
